# openmamba kernel specfile
# Copyright (C) 2004-2016 by Silvan Calarco
# Copyright (C) 2004-2006 by Davide Madrisan
# released under the GPL version 3 license
#
# To build a specific target:
#
# rpmbuild -ba --define="KERNEL_TARGET <target>" kernel.spec
#
# To cross-compile:
# rpmbuild -ba --target x86_64 --define="KERNEL_TARGET <target>" kernel.spec
#
# currently available targets (default is mamba):
# mamba,rt,custom
#
# NOTE: to allow multiple kernel major releases (3.x) cohexistence all patches releases
# have to be explicitly obsoletes, by adding such lines:
# Obsoletes:     kernel-%{KERNEL_TARGET}-source = %{kernel_ver}.1
# ...
# Obsoletes:     kernel-%{KERNEL_TARGET}-source = %{kernel_ver}.10

# Don't parametrize this, it's a check to avoid build a kernel without having
# edited the obsoletes needed for multiple kernel support
%define KERNEL_OBSOLETES_ARE_FOR_VERSION 4.1.23

#% define kernel_longterm 1
%define kernel_MAJver %(echo %version | cut -d. -f1)
%define kernel_majver %(echo %version | cut -d. -f1-2)
%define kernel_ver %(echo %version | cut -d. -f1-3)
%if "%{?kernel_longterm}" != "1"
%define kernel_pl  %(echo %version | cut -d. -f3)
%endif
%define        USE_DISTCC 0
%define        reiser4_ver 2.6.38
%define        xen_patchver 1
%define        rt_ver 3.10.6-rt3
%define        maj_rt_ver %(echo %rt_ver | cut -d. -f1-2)

%if "%{USE_DISTCC}" == "1"
   %define        DISTCC CC="ccache distcc" -j 12
%endif

# Build a mamba kernel if no target was specified
%if "%{?KERNEL_TARGET}" == ""
%ifarch x86_64
   %define     KERNEL_TARGET mamba-x86_64
%else
   %define     KERNEL_TARGET mamba
%endif
%endif

# define short kernel target name for Lilo
%define     KERNEL_TARGET_SHORT %{KERNEL_TARGET}

%define     target_cpu %{_target_cpu}
%define     DEPMOD /sbin/depmod

%define     KIMAGE_DEST vmlinuz
%if "%{_target_cpu}" == "i586"
   %define     KIMAGE arch/i386/boot/bzImage
   %define     target_cpu i386
%endif

%if "%{_target_cpu}" == "arm"
   %if "%{KERNEL_TARGET}" == "mamba-arm-dove"
      %define     KIMAGE arch/arm/boot/uImage
      %define     KIMAGE_DEST uImage
   %else
      %define     KIMAGE arch/arm/boot/zImage
   %endif
%endif

%if "%{_target_cpu}" == "x86_64"
   %if "%{KERNEL_TARGET}" == "mamba-xen"
   %define     KIMAGE arch/x86_64/boot/vmlinuz
   %else
   %define     KIMAGE arch/x86_64/boot/bzImage
   %endif
%endif

%if "%{_target_cpu}" == "ppc"
   %define     KIMAGE vmlinux
   %define     target_cpu powerpc
%endif

# disable internal dependency generator for scriptlets
%define _use_internal_dependency_generator 1

Name:          kernel
Version:       4.1.23
Release:       1mamba
Summary:       The Linux Kernel, the operating system core itself
Group:         System/Kernel and Hardware
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
#%if "%{?kernel_longterm}" == ""
Source0:       ftp://ftp.kernel.org/pub/linux/kernel/v%{kernel_MAJver}.x/linux-%{kernel_ver}.tar.xz
#%if "%{?kernel_pl}" != ""
#Source1:       http://www.kernel.org/pub/linux/kernel/v3.x/patch-%{version}.xz
#%endif
#%else
#Source0:       http://www.kernel.org/pub/linux/kernel/v2.6/longterm/v%{kernel_ver}/linux-%{version}.tar.bz2
#%endif
Source7:       %{name}-rt-i586-config
#Source8:       %{name}-%{kernel_majver}-mamba-ppc-config
Source9:       %{name}-custom-i586-config
Source11:      %{name}-%{kernel_majver}-mamba-config
Source12:      %{name}-%{kernel_majver}-mamba-x86_64-config
Source13:      %{name}-%{kernel_majver}-mamba-64GB-config
#Source14:      %{name}-%{kernel_majver}-mamba-xen-x86_64-config
Source15:      %{name}-%{kernel_majver}-mamba-arm-config
#Source16:      %{name}-%{kernel_majver}-mamba-64GB-rt-i586-config
#Source17:      %{name}-%{kernel_majver}-mamba-rt-i586-config
#Source18:      %{name}-%{kernel_majver}-mamba-arm-kirkwood-config
#Source19:      %{name}-%{kernel_majver}-mamba-x86_64-rt-config
Source20:      %{name}-%{kernel_majver}-mamba-arm-dove-config
Patch0:        kernel-2.6.35-430-scsi_header_fix.patch
# Ingo Molnar's RT patch
Patch1:        http://www.kernel.org/pub/linux/kernel/projects/rt/%{maj_rt_ver}/patch-%{rt_ver}.patch.xz
Patch3:        kernel-2.6.28.10-MSG_PEEK_race_msg.patch
Patch4:        http://www.kernel.org/pub/linux/kernel/people/edward/reiser4/reiser4-for-2.6/reiser4-for-%{reiser4_ver}.patch.bz2
Patch11:       kernel-3.2.1-8139cp.patch
Patch18:       kernel26-2.6.18-bt8xx.patch
Patch22:       kernel-2.6.20-freezer.patch
Patch23:       kernel-2.6.19-hda_snd_intel-null_pointer.patch
Patch24:       kernel-2.6.35-usbstorage-disable_delay_use.patch
Patch25:       kernel-2.6.21-VT3351_disable_msi.patch
Patch27:       kernel-2.6.21-kvm_wbinvd.patch
Patch29:       kernel-2.6.22-ppc_PM_NEEDS_RTC_LIB.patch
Patch30:       kernel-2.6.22-ppc_export_vgacon_remap_base.patch
Patch31:       kernel-2.6.26-snd_hda_intel_zepto.patch
Patch32:       kernel-2.6.26-fglrx_disable_gpl_check.patch
Patch33:       kernel-2.6.26-atl1_disable_TSO.patch
Patch36:       kernel-2.6.30-fglrx_flush_tlb_page.patch
Patch37:       kernel-2.6.30-wmi_fix.patch
#Patch38:       http://gentoo-xen-kernel.googlecode.com/files/xen-patches-%{kernel_ver}-%{xen_patchver}.tar.bz2
Patch39:       kernel-3.2.1-rtl8139too.patch
Patch40:       %{name}-2.6.33-lzo_decompressor_fix.patch
#Patch50:       %{name}-2.6.33-arm-copypage-gcc4.patch
#Patch51:       %{name}-2.6.33-mcp52xx_gpt_fix_build.patch
Patch52:       %{name}-2.6.33.7-make-3.82.patch
Patch53:       %{name}-2.6.33-dns_resolve_include.patch
Patch54:       %{name}-2.6.33-fix_dependence_for_intel_agp_module.patch
Patch55:       %{name}-2.6.35-CTI_USB-485-Mini_USB-Nano-485.patch
Patch56:       %{name}-2.6.33-tpm_calc_ordinal_duration.patch
Patch57:       %{name}-2.6.35.10-drm-radeon-r600-cs-checker-fixes.patch
Patch58:       %{name}-2.6.37.1-radeon_flickering_fix.patch
Patch59:       %{name}-2.6.35-vga_dont_ask.patch
Patch61:       %{name}-3.1-arm_missing_includes.patch
Patch62:       %{name}-2.6.38.6-arm-rtlwifi-eliminate_udelay.patch
Patch63:       %{name}-3.2-elantech.patch
Patch64:       %{name}-3.0.8-suspend_fix_firmware_task_freezing_feature.patch
Patch65:       %{name}-3.0.17-mm_limit_direct_reclaim_for_higher_order_allocations.patch
Patch66:       %{name}-3.0.17_mm_abort_reclaim_compation_if_compation_can_proceed.patch
Patch67:       %{name}-3.2-arm_remove_BUILD_BUG_ON_from_bug_h.patch 
Patch68:       %{name}-3.2.9-asix_sitecom_ln_031.patch
Patch69:       %{name}-3.2.16-ipw2200_fix.patch
Patch70:       %{name}-3.2-option_add_Huawey-E352.patch
Patch71:       kernel-3.7.1-libata_restore_acpi_disable_functionality.patch
Patch72:       kernel-3.4.24-ACPI_do_not_use_Lid_and_Sleep_button_for_S5_wakeup.patch
Patch73:       kernel-3.8.3-arm-exynosdrm-buildfix.patch
Patch74:       kernel-3.8.3-arm-imx-drm-buildfix.patch
Patch75:       kernel-3.10.2-arm-mtd_omap2_allow_building_as_a_module.patch
# https://dev.openwrt.org/browser/trunk/target/linux/generic/patches-3.12/100-overlayfs.patch?order=name
Patch100:      kernel-3.14.2-overlayfs.patch
## overlayfs: get the 12 patches above Linux 3.6 tag from:
## http://git.kernel.org/?p=linux/kernel/git/mszeredi/vfs.git;a=shortlog;h=refs/heads/overlayfs.v14
#Patch100:      0001-vfs-add-i_op-dentry_open.patch
#Patch101:      0002-vfs-export-do_splice_direct-to-modules.patch
#Patch102:      0003-vfs-export-__inode_permission-to-modules.patch
#Patch103:      0004-vfs-introduce-clone_private_mount.patch
#Patch104:      0005-overlay-filesystem.patch
#Patch105:      0006-overlayfs-add-statfs-support.patch
#Patch106:      0007-overlayfs-implement-show_options.patch
#Patch107:      0008-overlay-overlay-filesystem-documentation.patch
#Patch108:      0009-fs-limit-filesystem-stacking-depth.patch
URL:           http://www.kernel.org
License:       GPL
## AUTOBUILDREQ-BEGIN
## AUTOBUILDREQ-END
#BuildRequires: /bin/bash /bin/sh
#BuildRequires: module-init-tools >= 3.1
%if "%{USE_DISTCC}" == "1"
BuildRequires: distcc ccache
%endif
BuildRoot:     %{_tmppath}/%{name}-%{version}-build
%define buildroot %{_tmppath}/%{name}-%{KERNEL_TARGET}-build

%description
The Linux Kernel, the operating system core itself.
The kernel package contains the Linux kernel (%{KIMAGE_DEST}), the operating system core itself.
The kernel handles the basic functions of the operating system: memory allocation, process allocation, device input and output, etc.
This is the source package used to build kernel for different architectures and targets.

%if "%{?KERNEL_TARGET}" != ""
%package %{KERNEL_TARGET}
Group:         System/Kernel and Hardware
Summary:       The Linux kernel, the operating system core itself
%endif
Requires(post):dracut
Requires(post):module-init-tools >= 3.1
%if "%{_target_cpu}" != "arm"
Requires(pre): bootloader
%endif
Requires:      kernelwireless-%{KERNEL_TARGET}-%{kernel_ver}
Requires:      kernelsound-%{KERNEL_TARGET}-%{kernel_ver}
Requires:      linux-firmware
Provides:      kernel = %{version}
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET} < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET} = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET} = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET} = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET} = %{kernel_majver}.18
## KERNELOBSOLETES-END

%description %{KERNEL_TARGET}
The Linux Kernel, the operating system core itself.
The kernel package contains the Linux kernel (%{KIMAGE_DEST}), the operating system core itself.
The kernel handles the basic functions of the operating system: memory allocation, process allocation, device input and output, etc.
This kernel was build for %{_target_cpu} architecture and the following target: %{?KERNEL_TARGET}.

%package %{KERNEL_TARGET}-source
Group:         Development/Kernel
Summary:       The source code for the Linux kernel
Requires:      kernel-%{KERNEL_TARGET}-headers == %{version}-%{release}
Provides:      kernelsource = %{version}
Obsoletes:     kernel-alsa-devel
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET}-source < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET}-source = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET}-source = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET}-source = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET}-source = %{kernel_majver}.18
## KERNELOBSOLETES-END

%description %{KERNEL_TARGET}-source
The kernel-source package contains the source code files for the Linux kernel.
The source files can be used to build a custom kernel that is better tuned to your particular hardware, if you are so inclined (and you know what you're doing).
This kernel sources are configured for %{TARGET_CPU} architecture and the following target: %{?KERNEL_TARGET}.

%package %{KERNEL_TARGET}-headers
Group:         Development/Kernel
Summary:       Headers, scripts, configuration and Makefile for the linux kernel
Provides:      kernelheaders = %{version}
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET}-headers < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET}-headers = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET}-headers = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET}-headers = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET}-headers = %{kernel_majver}.18
## KERNELOBSOLETES-END

%description %{KERNEL_TARGET}-headers
The kernel-headers package contains the headers, scripts, configuration and Makefile to develop with the linux kernel
The kernel-headers can be used to build modules for the kernel.
This kernel headers are configured for %{TARGET_CPU} architecture and the following target: %{?KERNEL_TARGET}.

%package %{KERNEL_TARGET}-headers-sanitised
Group:         Development/Kernel
Summary:       Sanitised kernel headers used for glibc build
Provides:      kernelsanitisedheaders = %{version}
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET}-headers-sanitised < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET}-headers-sanitised = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET}-headers-sanitised = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET}-headers-sanitised = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET}-headers-sanitised = %{kernel_majver}.18
## KERNELOBSOLETES-END

%description %{KERNEL_TARGET}-headers-sanitised
Sanitised kernel headers used for glibc build.
This kernel sanitised headers are configured for %{TARGET_CPU} architecture and the following target: %{?KERNEL_TARGET}.

%package %{KERNEL_TARGET}-sound
Group:         System/Kernel and Hardware
Summary:       The kernel sound subsystem
Provides:      kernelsound = %{version}
Provides:      kernelsound-%{KERNEL_TARGET}-%{kernel_ver}
Requires:      kernel-%{KERNEL_TARGET} == %{version}-%{release}
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET}-sound < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET}-sound = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET}-sound = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET}-sound = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET}-sound = %{kernel_majver}.18
## KERNELOBSOLETES-END

%description %{KERNEL_TARGET}-sound
The kernel-sound package contains the native kernel sound subsystem with ALSA drivers.
This is packaged apart because more up-to-date drivers are provided by kernel-%{KERNEL_TARGET}-extramodules-source package which uses more up-to-date drivers from the ALSA project.

%package %{KERNEL_TARGET}-wireless
Group:         System/Kernel and Hardware
Summary:       The kernel wireless subsystem
Provides:      kernelwireless = %{version}
Provides:      kernelwireless-%{KERNEL_TARGET}-%{kernel_ver}
Requires:      kernel-%{KERNEL_TARGET} == %{version}-%{release}
Requires:      iwlwifi-firmware
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET}-wireless < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET}-wireless = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET}-wireless = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET}-wireless = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET}-wireless = %{kernel_majver}.18
## KERNELOBSOLETES-END
Requires:      crda

%description %{KERNEL_TARGET}-wireless
The kernel-wireless package contains the native kernel wireless subsystem with drivers.
This is packaged apart because more up-to-date drivers are provides by kernel-%{KERNEL_TARGET}-extramodules package which uses drivers from the wireless-compat project.

%package %{KERNEL_TARGET}-firmware
Group:         System/Kernel and Hardware
Summary:       Firmware files used by the Linux Kernel
Provides:      kernelfirmware = %{version}
Requires:      kernel-%{KERNEL_TARGET} == %{version}-%{release}
## KERNELOBSOLETES-BEGIN 3.18
Obsoletes:     kernel-%{KERNEL_TARGET}-firmware < 3.10
Obsoletes:     kernel-%{KERNEL_TARGET}-firmware = %{kernel_majver}.14
Obsoletes:     kernel-%{KERNEL_TARGET}-firmware = %{kernel_majver}.15
Obsoletes:     kernel-%{KERNEL_TARGET}-firmware = %{kernel_majver}.17
Obsoletes:     kernel-%{KERNEL_TARGET}-firmware = %{kernel_majver}.18
## KERNELOBSOLETES-END
Provides:      linux_firmware

%description %{KERNEL_TARGET}-firmware
Firmware files used by the Linux Kernel.

%prep
[  "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%if "%{version}" != "%{KERNEL_OBSOLETES_ARE_FOR_VERSION}"
   echo "ERROR: please edit obsoletes for multiple kernel support before proceeding."
   exit 1
%endif

ld -v | grep "gold" && {
   echo "Error: ld GOLD detected, which is incompatible with this package. Aborting."
   exit 1
}

%if "%{?KERNEL_TARGET}" == ""
   echo "No target specified, aborting."
   exit 1
%else
   echo "I'm going to build a %{KERNEL_TARGET} kernel..."
%endif

%setup -q -c -n %{name}-%{kernel_ver}%{?KERNEL_TARGET}
#-D -T
#:<< ___EOF
%if "%{?kernel_longterm}" == ""
mv linux-%{kernel_ver}/* .
rm -r linux-%{kernel_ver}
%else
mv linux-%{version}/* .
rm -r linux-%{version}
%endif

# add here subrelease patch
#%if "%{?kernel_longterm}" != "1"
#%if "%{?kernel_pl}" != ""
#echo "%{?kernel_pl}"
#xzcat -c %{SOURCE1} >/dev/null || exit 1
#xzcat -c %{SOURCE1} | patch -p1
#%endif
#%endif
#sed -i "s/\(SUBLEVEL =\).*/\1/" Makefile

#
# patch and configure STANDARD kernel
#

make mrproper

# create build dirs for each kernel
# and copy proper configuration
%if %{_target_cpu} == i586
   case %{?KERNEL_TARGET} in
      mamba) kernel_cfg=%{SOURCE11}
               ;;
      mamba-64GB) kernel_cfg=%{SOURCE13}
               ;;
      custom) kernel_cfg=%{SOURCE9}
               ;;
      mamba-rt) kernel_cfg=%{SOURCE17}
               # add RT patches
               xz -cd %{PATCH1} | patch -p1
			   rm -f localversion-rt
               ;;
      mamba-64GB-rt) kernel_cfg=%{SOURCE16}
               # add RT patches
               xz -cd %{PATCH1} | patch -p1
			   rm -f localversion-rt
               ;;
   esac
%endif
%if %{_target_cpu} == x86_64
   case %{?KERNEL_TARGET} in
      mamba-x86_64) kernel_cfg=%{SOURCE12}
               ;;
      mamba-x86_64-rt) kernel_cfg=%{SOURCE19}
               # add RT patches
               xz -cd %{PATCH1} | patch -p1
			   rm -f localversion-rt
               ;;
      mamba-xen) kernel_cfg=%{SOURCE14}
#               mkdir patches
#               cd patches
#               tar xjf %{PATCH38}
#               cd ..
#               for f in patches/*.patch1; do
#                  echo "Applying patch $f"
#                  patch -p1 < $f
#               done
#               rm -rf patches
               ;;
   esac
%endif
%if %{_target_cpu} == arm
   case %{?KERNEL_TARGET} in
      mamba-arm) kernel_cfg=%{SOURCE15} ;;
      mamba-arm-kirkwood) kernel_cfg=%{SOURCE18} ;;
      mamba-arm-dove) kernel_cfg=%{SOURCE20} ;;
   esac
## apply arm copypage gcc4 patch
#   patch -p1 < %{PATCH50}
%endif
%if %{_target_cpu} == ppc
   case %{?KERNEL_TARGET} in
      mamba-ppc) kernel_cfg=%{SOURCE8}
#             patch -p1 < %{PATCH29}
#             patch -p1 < %{PATCH30}
             ;;
      *) echo "Kernel Target %{?KERNEL_TARGET} not supported on ppc; aborting."
         exit 1
         ;;
   esac
%endif
cp $kernel_cfg ./.config

# 8139cp patch
#%patch11 -p1
# usbstorage disable delay_use patch (disabled since kernel 2.6.35 because patched from 5 to 1 sec instead of 5 to 0)
%patch24 -p1
# FIXME: this patch disable GPL check on __rcu_read_lock and __rcu_read_unlock
#        for use with proprietary ATI fglrx drivers
#%patch32 -p1
# reiser4 support patch
#%patch4 -p1
# export flushtlb_page symbol (for fglrx driver)
%patch36 -p0
## fixes a kernel panic with wmi when stack protector is enabled
#%patch37 -p1
# rtl_8139too patch
%patch39 -p1
# fix mpc52xx_gpt.c build (powerpc)
#% patch51 -p1
%patch53 -p1
%patch59 -p1
## Elantech touchpad patch generated from http://people.debian.org/~julien/lp681904/psmouse-elantech-lp681904-1.tar.bz2
#%patch63 -p1
#%patch73 -p1
#%patch74 -p1
#%patch75 -p1

# overlayfs patches
#%patch100 -p1
#% patch101 -p1
#% patch102 -p1
#% patch103 -p1
#% patch104 -p1
#% patch105 -p1
#% patch106 -p1
#% patch107 -p1
#% patch108 -p1

%build
#:<< ___EOF
#
# build kernel for given target
#
sed -i 's@/usr/bin/env@/bin/env@' ./arch/ia64/scripts/unwcheck.py
ARCH=%{target_cpu} make oldconfig
cp Makefile Makefile.orig
sed -i "s/\(EXTRAVERSION =\).*/\1 %{?KERNEL_TARGET}/" Makefile
ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} all %{?KIMAGE_TARGET}

if [ "%{?KERNEL_TARGET}" = "mamba-arm-dove" ]; then
   # See www.solid-run.com/mw/index.php?title=Device_Tree
   ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} uImage
   cp arch/arm/boot/zImage arch/arm/boot/zImage.orig
   ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} dove-cubox.dtb
   cat arch/arm/boot/zImage.orig arch/arm/boot/dts/dove-cubox.dtb > arch/arm/boot/zImage
   ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} uImage
fi

#%if %{_target_cpu} == arm
#ARCH=%{target_cpu} make CROSS_COMPILE=%{_target_platform}- %{?_smp_mflags} %{?DISTCC} uImage
#%endif

%install
[  "%{buildroot}" != / ] && rm -rf "%{buildroot}"

# create system dirs in install environment
install -d %{buildroot}{/usr/src/,/boot,%{_initrddir},/lib/modules}

ARCH=%{target_cpu} make \
   modules_install INSTALL_MOD_PATH=%{buildroot} DEPMOD=%{DEPMOD}

install -m0644 modules.builtin %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/
install -m0644 modules.order %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/

(cd %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}
rm -f build && ln -sf /usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET} build )

# copy modules to major directory location (e.g. 2.6.11) and create
# a symlink for the current 4 numbers release (e.g. 2.6.11.11) pointing to
# that dir
#if  [ "%{kernel_pl}" ]; then
#   mv %{buildroot}/lib/modules/%{version}%{?KERNEL_TARGET} %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}
#   ln -s %{kernel_ver}%{?KERNEL_TARGET} %{buildroot}/lib/modules/%{version}%{?KERNEL_TARGET}
#fi

cp %{KIMAGE} %{buildroot}/boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_TARGET}

#%if %{_target_cpu} == arm
#cp arch/arm/boot/uImage %{buildroot}/boot/uImage-%{kernel_ver}%{?KERNEL_TARGET}
#%endif

cp System.map %{buildroot}/boot/System.map-%{kernel_ver}%{?KERNEL_TARGET}

# recreate kernel sources
[ -e kernel-headers.files ] && rm -f kernel-headers.files
[ -e kernel-source.files ] && rm -f kernel-source.files
cp -R %{_builddir}/%{name}-%{kernel_ver}%{?KERNEL_TARGET} %{buildroot}/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}

cd %{buildroot}/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}
ARCH=%{target_cpu} make mrproper
%if %{_target_cpu} == i586
   case %{?KERNEL_TARGET} in
      mamba) kernel_cfg=%{SOURCE11} ;;
      mamba-64GB) kernel_cfg=%{SOURCE13} ;;
      mamba-64GB-rt) kernel_cfg=%{SOURCE16} ;;
      mamba-rt) kernel_cfg=%{SOURCE17} ;;
      custom) kernel_cfg=%{SOURCE9} ;;
      rt) kernel_cfg=%{SOURCE7} ;;
   esac
%endif
%if %{_target_cpu} == x86_64
   case %{?KERNEL_TARGET} in
      mamba-x86_64) kernel_cfg=%{SOURCE12} ;;
      mamba-x86_64-rt) kernel_cfg=%{SOURCE19} ;;
      mamba-xen) kernel_cfg=%{SOURCE14} ;;
   esac
%endif
%if %{_target_cpu} == arm
   case %{?KERNEL_TARGET} in
      mamba-arm) kernel_cfg=%{SOURCE15} ;;
      mamba-arm-kirkwood) kernel_cfg=%{SOURCE18} ;;
      mamba-arm-dove) kernel_cfg=%{SOURCE20} ;;
   esac
%endif
%if %{_target_cpu} == ppc
   case %{?KERNEL_TARGET} in
      mamba-ppc) kernel_cfg=%{SOURCE8} ;;
   esac
%endif

cp $kernel_cfg %{buildroot}/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/.config
cp %{_builddir}/%{name}-%{kernel_ver}%{?KERNEL_TARGET}/Module.symvers %{buildroot}/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}
#cp Makefile Makefile.orig
#sed -i "s/\(EXTRAVERSION =.*\)/\1%{?KERNEL_TARGET}/" Makefile
#%if "%{_target_platform}" == "%{_build}"

%ifarch x86_64
# FIXME: problems cross-compiling and running x86_64 tools on x86; building as x86 code for now
ARCH=%{target_cpu} make \
   HOSTCC=%{_build}-gcc \
   CROSS_COMPILE=%{_target_platform}- \
   prepare scripts oldconfig
%else
ARCH=%{target_cpu} make \
   HOSTCC=%{_target_platform}-gcc \
   CROSS_COMPILE=%{_target_platform}- \
   prepare scripts oldconfig
%endif

cp -a include/generated/* include/linux/
#%endif
rm .config.old

##
## lilo configuration
##
#cat > %{buildroot}%{_sysconfdir}/lilo.d/openmamba-%{kernel_ver}%{?KERNEL_TARGET}-%{release} <<EOF
#image=/boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_TARGET}
#      label="openmamba-%{KERNEL_TARGET_SHORT}"
#      root=
#      initrd=/boot/initramfs-%{kernel_ver}%{?KERNEL_TARGET}.img
#      append="quiet splash=silent,fadein console=tty1 video=uvesafb:1024x768-32,ywrap,mtrr:3"
#      read-only
#EOF

##
## grub configuration
##
#mkdir -p %{buildroot}%{_sysconfdir}/grub/conf.d
#cat > %{buildroot}%{_sysconfdir}/grub/conf.d/openmamba-%{kernel_ver}%{?KERNEL_TARGET}-%{release} <<EOF
#title openmamba (kernel %{kernel_ver}%{?KERNEL_TARGET})
#root
#kernel /boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_TARGET} root= video=uvesafb:1024x768-32,ywrap,mtrr:3 quiet splash=silent,fadein console=tty1
#initrd /boot/initramfs-%{kernel_ver}%{?KERNEL_TARGET}.img
#EOF

##
## grub2 configuration
##
#mkdir -p %{buildroot}%{_sysconfdir}/grub2/conf.d
#cat > %{buildroot}%{_sysconfdir}/grub2/conf.d/openmamba-%{version}%{?KERNEL_TARGET}-%{release} <<EOF
#menuentry "openmamba (kernel %{version}%{?KERNEL_TARGET})" {
#    linux /boot/%{KIMAGE_DEST}-%{version}%{?KERNEL_TARGET} root= video=vesafb:1024x768-32,ywrap,mtrr:3 quiet splash=silent,fadein console=tty1
#    initrd /boot/initramfs-%{version}%{?KERNEL_TARGET}.img
#}
#EOF

# clean modules files created by depmod
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/modules.{alias,alias.bin,ccwmap,dep,dep.bin,devname,ieee1394map}
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/modules.{inputmap,isapnpmap,ofmap,pcimap,seriomap,softdep}
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/modules.{symbols,symbols.bin,usbmap}

# remove .tmp files if any
rm -f %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/.tmp* || true

# clean a wrong symlink
[ -L %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch/ppc/include/asm ] && \
{
   rm -f %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch/ppc/include/asm
   ln -sf ../../../include/asm %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch/ppc/include/asm
}

# fix symlink pointing to sources
rm -f %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/source
ln -s %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET} %{buildroot}/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/source

#
# create kernel-source.files and kernel-headers.files
#
cd %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}

splitdirs="block crypto drivers fs ipc kernel lib mm net security sound"
case %{_target_cpu} in
   i586|x86_64) headers_arch="x86" ;;
   arm) headers_arch="arm" ;;
   ppc) headers_arch="powerpc" ;;
esac

# discovered while building nvidia 304.88 for 3.10
[ -e %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/include/uapi/asm ] || \
   ln -s ../../arch/$headers_arch/include/uapi/asm \
      %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/include/uapi/asm

[ -e %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/include/asm ] || \
   ln -s ../arch/$headers_arch/include/asm include/asm
   
find $splitdirs -type f -name *.h -exec \
   echo "%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/"{} >> \
   %{_builddir}/kernel-%{kernel_ver}%{?KERNEL_TARGET}/kernel-headers.files \;

%if "%{with_full_source}" == "1"
find $splitdirs -type f -not -name *.h -exec \
   echo "%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/"{} >> \
   %{_builddir}/kernel-%{kernel_ver}%{?KERNEL_TARGET}/kernel-source.files \;
%else
touch %{_builddir}/kernel-%{kernel_ver}%{?KERNEL_TARGET}/kernel-source.files
find $splitdirs -type f -not -name *.h -exec rm -f {} \;
rm -rf firmware samples virt
%endif

archs=" `ls %{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch` "

for i in $archs; do
   [ "$i" == "$headers_arch" ] || \
%if "%{with_full_source}" == "1"
      echo "%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch/$i" >> \
   %{_builddir}/kernel-%{kernel_ver}%{?KERNEL_TARGET}/kernel-source.files
%else
      rm -rf arch/$i
%endif
done

echo "%{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch/$headers_arch" >> \
   %{_builddir}/kernel-%{kernel_ver}%{?KERNEL_TARGET}/kernel-headers.files

# install sanitised headers used by glibc
%ifarch x86_64
ARCH=%{target_cpu} make headers_install \
   HOSTCC=%{_build}-gcc \
   CROSS_COMPILE=%{_target_platform}- \
   INSTALL_HDR_PATH=%{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{KERNEL_TARGET}/usr
%else
ARCH=%{target_cpu} make headers_install \
   HOSTCC=%{_target_platform}-gcc \
   CROSS_COMPILE=%{_target_platform}- \
   INSTALL_HDR_PATH=%{buildroot}%{_prefix}/src/linux-%{kernel_ver}%{KERNEL_TARGET}/usr
%endif

# from kernel 3.0.4 patch
rm -f %{buildroot}/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/MAINTAINERS.orig

%clean
[  "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%pre %{?KERNEL_TARGET}
if [ $1 -gt 1 ]; then
   # update or downgrade
   %if "%{_target_cpu}" == "i586"
      [ -x /sbin/lilo-config ] &&
         /sbin/lilo-config -q --keep-default --del "openmamba-%{?KERNEL_TARGET_SHORT}"
   %endif
   %if "%{_target_cpu}" == "x86_64"
      [ -x /sbin/lilo-config ] &&
         /sbin/lilo-config -q --keep-default --del "openmamba-%{?KERNEL_TARGET_SHORT}"
   %endif
   %if "%{_target_cpu}" == "ppc"
      /usr/sbin/ybin
   %endif
   :
fi
exit 0

%post %{?KERNEL_TARGET}
#   %if "%{_target_cpu}" == "i586"
#      if [ -x /sbin/lilo-config ]; then
#         /sbin/lilo-config --killdevfs
#         /sbin/lilo-config --add \
#            %{_sysconfdir}/lilo.d/openmamba-%{kernel_ver}%{?KERNEL_TARGET}-%{release}
#         /sbin/lilo
#      fi
#   %endif
#   %if "%{_target_cpu}" == "x86_64"
#      if [ -x /sbin/lilo-config ]; then
#         /sbin/lilo-config --killdevfs
#         /sbin/lilo-config --add \
#            %{_sysconfdir}/lilo.d/openmamba-%{kernel_ver}%{?KERNEL_TARGET}-%{release}
#         /sbin/lilo
#      fi
#   %endif

#if [ $1 -eq 0 ]; then
## uninstalling the rpm package
#   %if "%{_target_cpu}" == "i586"
#      if [ -x /sbin/lilo-config ]; then
#         /sbin/lilo-config -q --del "openmamba-%{?KERNEL_TARGET_SHORT}"
#         /sbin/lilo
#      fi
#   %endif
#   %if "%{_target_cpu}" == "x86_64"
#      if [ -x /sbin/lilo-config ]; then
#         /sbin/lilo-config -q --del "openmamba-%{?KERNEL_TARGET_SHORT}"
#         /sbin/lilo
#      fi
#   %endif
#   :
#fi

exit 0

%postun %{?KERNEL_TARGET}
# erase this package
if [ $1 -eq 0 ]; then
   [ -f /boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_TARGET} ] ||
      rm -f /boot/initramfs-%{kernel_ver}%{?KERNEL_TARGET}.img
fi
exit 0

%post %{?KERNEL_TARGET}-wireless
# new install or upgrade
if [ $1 -ge 1 ]; then
   /sbin/depmod -a -F /boot/System.map-%{kernel_ver}%{?KERNEL_TARGET} \
      %{kernel_ver}%{?KERNEL_TARGET} &>/dev/null
fi
exit 0

%post %{?KERNEL_TARGET}-sound
# new install or upgrade
if [ $1 -ge 1 ]; then
   /sbin/depmod -a -F /boot/System.map-%{kernel_ver}%{?KERNEL_TARGET} \
      %{kernel_ver}%{?KERNEL_TARGET} &>/dev/null
fi
exit 0

%posttrans %{?KERNEL_TARGET}
# clean our orphan old initramfs
ls /boot/initramfs-*-failsafe.img | \
while read line; do
   k=${line/\/boot\/initramfs-}
   k=${k/-failsafe.img}
   [ -e /boot/vmlinuz-$k ] || \
       rm -f /boot/initramfs-$k.img /boot/initramfs-$k-failsafe.img
done
# clean old and empty /usr/src/linux-* directories
for f in /usr/src/linux-*; do
 if [ ! -L $f ]; then
  a=`find $f -type f -a -not -name MARKER -print -quit | wc -l`
  if [ $a -eq 0 -a "$f" != "/" ]; then
   rm -rf $f
  fi
 fi
done

# new install or upgrade
/sbin/depmod -a -F /boot/System.map-%{kernel_ver}%{?KERNEL_TARGET} \
   %{kernel_ver}%{?KERNEL_TARGET} &>/dev/null

# create local system initramfs
/usr/sbin/mkinitrd -f /boot/initramfs-%{kernel_ver}%{?KERNEL_TARGET}.img %{kernel_ver}%{?KERNEL_TARGET}

# create system-wide "failsafe" initramfs
/usr/sbin/dracut -f --filesystems "ext3 squashfs isofs reiserfs ext4" \
       --nomdadmconf --nolvmconf -k /lib/modules/%{kernel_ver}%{?KERNEL_TARGET} \
       /boot/initramfs-%{kernel_ver}%{?KERNEL_TARGET}-failsafe.img %{kernel_ver}%{?KERNEL_TARGET}

# all done, now ring grub-update
%if "%{_target_cpu}" == "i586"
  if [ -x /usr/sbin/grub-update ]; then
     /usr/sbin/grub-update
  fi
  if [ -x /usr/sbin/update-grub ]; then
     /usr/sbin/update-grub 2>/dev/null
     grub-set-default 0
  fi
%endif
%if "%{_target_cpu}" == "x86_64"
  if [ -x /usr/sbin/grub-update ]; then
     /usr/sbin/grub-update
  fi
  if [ -x /usr/sbin/update-grub ]; then
     /usr/sbin/update-grub 2>/dev/null
     grub-set-default 0
  fi
%endif
%if "%{_target_cpu}" == "ppc"
  /usr/sbin/ybin
%endif
exit 0

%post %{KERNEL_TARGET}-headers
# touch file so it results up-to-date on make
if [ $1 -ge 1 ]; then
   touch %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/include/config/MARKER
   [ -x /usr/sbin/dkms ] && dkms autoinstall -q --kernelver %{kernel_ver}%{?KERNEL_TARGET} || true
   ln -snf %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET} %{_prefix}/src/linux-%{?KERNEL_TARGET}
fi
exit 0

%post %{KERNEL_TARGET}-headers-sanitised
if [ $1 -ge 1 ]; then
   ln -snf %{_prefix}/src/linux-%{kernel_ver}%{?KERNEL_TARGET} %{_prefix}/src/linux-%{?KERNEL_TARGET}
fi
exit 0

%files %{?KERNEL_TARGET}
%defattr (-, root, root)
/boot/System.map-%{kernel_ver}%{?KERNEL_TARGET}
/boot/%{KIMAGE_DEST}-%{kernel_ver}%{?KERNEL_TARGET}
#%if %{_target_cpu} == arm
#/boot/uImage-%{kernel_ver}%{?KERNEL_TARGET}
#%endif
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/modules.builtin
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/modules.builtin.bin
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/modules.order
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/build
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/arch
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/block
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/block/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/crypto
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/crypto/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/fs
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/fs/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/kernel
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/kernel/*.ko
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/kernel/locking
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/kernel/locking/*.ko
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/kernel/time
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/kernel/time/*.ko
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/lib
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/lib/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/net
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/net/*
%dir /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/security
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/security/*
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/sound/soundcore.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/build
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/source
#%{_sysconfdir}/lilo.d/openmamba-%{kernel_ver}%{?KERNEL_TARGET}-%{release}
#%{_sysconfdir}/grub/conf.d/openmamba-%{kernel_ver}%{?KERNEL_TARGET}-%{release}
#%{_sysconfdir}/grub2/conf.d/openmamba-%{version}%{?KERNEL_TARGET}-%{release}
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/usb/cdc_ether.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/usb/rndis_host.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/usb/usbnet.ko
%ifnarch arm
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/adm8211.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/libertas_cs.ko
%endif
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/at76_usb.ko
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/ath5k/ath5k.ko
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/ath9k/ath9k.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/b43/b43.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/b43legacy/b43legacy.ko
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/iwlwifi/iwl3945.ko
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/iwlwifi/iwlagn.ko
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/iwlwifi/iwlcore.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/libertas.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/libertas_sdio.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas_tf/libertas_tf.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas_tf/libertas_tf_usb.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/usb8xxx.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/mac80211_hwsim.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/p54/p54common.ko
%ifnarch arm
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/p54/p54pci.ko
%endif
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/p54/p54usb.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rndis_wlan.ko
%ifnarch arm
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2400pci.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2500pci.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2x00pci.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt61pci.ko
%endif
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2500usb.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2x00lib.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2x00usb.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt73usb.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/zd1211rw/zd1211rw.ko
#%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/bcm43xx/bcm43xx.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/ssb/ssb.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/net/mac80211/mac80211.ko
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/net/wireless/cfg80211.ko

%files %{?KERNEL_TARGET}-sound
%defattr (-,root,root)
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/sound
%exclude /lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/sound/soundcore.ko

%files %{KERNEL_TARGET}-wireless
%defattr(-,root,root)
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/usb/cdc_ether.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/usb/rndis_host.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/usb/usbnet.ko
%ifnarch arm
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/adm8211.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/libertas_cs.ko
%endif
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/at76_usb.ko
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/ath5k/ath5k.ko
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/ath9k/ath9k.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/b43/b43.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/b43legacy/b43legacy.ko
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/iwlwifi/iwl3945.ko
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/iwlwifi/iwlagn.ko
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/iwlwifi/iwlcore.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/libertas.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/libertas_sdio.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas_tf/libertas_tf.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas_tf/libertas_tf_usb.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/libertas/usb8xxx.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/mac80211_hwsim.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/p54/p54common.ko
%ifnarch arm
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/p54/p54pci.ko
%endif
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/p54/p54usb.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rndis_wlan.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2500usb.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2x00lib.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2x00usb.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt73usb.ko
%ifnarch arm
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2400pci.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2500pci.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt2x00pci.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/rt2x00/rt61pci.ko
%endif
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/zd1211rw/zd1211rw.ko
#/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/net/wireless/bcm43xx/bcm43xx.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/drivers/ssb/ssb.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/net/mac80211/mac80211.ko
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/kernel/net/wireless/cfg80211.ko

%files %{KERNEL_TARGET}-source -f kernel-source.files
%defattr(-,root,root)
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/arch/.gitignore
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/Documentation
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/REPORTING-BUGS
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/gen_init_cpio.c
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/initramfs_data.S
#/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/initramfs_data.bz2.S
#/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/initramfs_data.gz.S
#/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/initramfs_data.lzma.S
#/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/initramfs_data.lzo.S
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/Kconfig
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/Makefile
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/.gitignore
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/tools
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/.missing-syscalls.d
%if "%{with_full_source}" == "1"
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/block
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/firmware
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/samples
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/virt
%endif

%files %{KERNEL_TARGET}-headers-sanitised
%defattr(-,root,root)
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/usr/include

%files %{KERNEL_TARGET}-headers -f kernel-headers.files
%defattr(-,root,root)
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/COPYING
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/CREDITS
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/Kbuild
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/Kconfig
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/drivers
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/include
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/init
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/Makefile
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/Makefile.orig
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/Module.symvers
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/MAINTAINERS
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/README
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/scripts
/usr/src/linux-%{kernel_ver}%{?KERNEL_TARGET}/.config
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/build
/lib/modules/%{kernel_ver}%{?KERNEL_TARGET}/source

%files %{?KERNEL_TARGET}-firmware
%defattr (-, root, root)
/lib/firmware/*

%changelog
* Tue May 03 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.23-1mamba
- update to 4.1.23

* Sat Mar 05 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.18-1mamba
- update to 4.1.18

* Tue Feb 16 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.17-2mamba
- fix obsolete for previous version to replace

* Fri Feb 12 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.17-1mamba
- update to 4.1.17

* Thu Jan 07 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.15-1mamba
- update to 4.1.15

* Thu Dec 10 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 4.1.14-1mamba
- update to 4.1.14

* Fri Sep 25 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-4mamba
- unset CONFIG_COMPAT_VDSO to  fix chromium crashes on x86

* Sun Sep 20 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-3mamba
- fix obsoletes for autoupdate

* Sat Sep 19 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-2mamba
- set CONFIG_DEVPTS_MULTIPLE_INSTANCES=y to fix recent problems with systemd-logind

* Fri Sep 04 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.21-1mamba
- update to 3.18.21
- posttrans: delete our old orphan initramfs from /boot

* Mon Aug 17 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.20-1mamba
- update to 3.18.20

* Thu May 21 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.14-1mamba
- update to 3.18.14
- set CONFIG_PID_NS=y

* Wed Apr 15 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.11-1mamba
- update to 3.18.11

* Thu Mar 26 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.10-1mamba
- update to 3.18.10

* Sun Feb 22 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.18.7-1mamba
- update to 3.18.7

* Thu Jan 29 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.30-1mamba
- update to 3.14.30

* Sat Dec 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.27-1mamba
- update to 3.14.27

* Tue Dec 16 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.26-1mamba
- update to 3.14.26

* Sat Nov 22 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.25-1mamba
- update to 3.14.25

* Thu Nov 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.24-2mamba
- restore SUBLEVEL in version to work better with dkms, but prepare to some bugfixing elsewhere

* Thu Nov 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.24-1mamba
- update to 3.14.24

* Fri Oct 31 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.23-1mamba
- update to 3.14.23

* Sat Oct 04 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.19-1mamba
- update to 3.14.19

* Tue Jul 08 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.11-1mamba
- update to 3.14.11

* Thu Jul 03 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.10-1mamba
- update to 3.14.10

* Sat Jun 07 2014 Automatic Build System <autodist@mambasoft.it> 3.14.5-1mamba
- automatic version update by autodist

* Sun May 18 2014 Automatic Build System <autodist@mambasoft.it> 3.14.4-1mamba
- automatic version update by autodist

* Wed May 07 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.3-1mamba
- update to 3.14.3

* Sat May 03 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.2-1mamba
- update to 3.14.2

* Thu Mar 27 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.15-1mamba
- update to 3.12.15

* Sat Mar 01 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.13-1mamba
- update to 3.12.13

* Fri Jan 17 2014 Automatic Build System <autodist@mambasoft.it> 3.12.8-1mamba
- automatic version update by autodist

* Sun Jan 12 2014 Automatic Build System <autodist@mambasoft.it> 3.12.7-1mamba
- automatic version update by autodist

* Mon Dec 23 2013 Automatic Build System <autodist@mambasoft.it> 3.12.6-1mamba
- automatic version update by autodist

* Sun Dec 15 2013 Automatic Build System <autodist@mambasoft.it> 3.12.5-1mamba
- automatic version update by autodist

* Mon Dec 09 2013 Automatic Build System <autodist@mambasoft.it> 3.12.4-1mamba
- automatic version update by autodist

* Sat Dec 07 2013 Automatic Build System <autodist@mambasoft.it> 3.12.3-1mamba
- automatic version update by autodist

* Sat Nov 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.2-1mamba
- update to 3.12.2

* Wed Oct 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.17-1mamba
- update to 3.10.17

* Sun Sep 15 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.12-1mamba
- update to 3.10.12

* Wed Sep 04 2013 Automatic Build System <autodist@mambasoft.it> 3.10.10-1mamba
- update to 3.10.10

* Thu Aug 22 2013 Automatic Build System <autodist@mambasoft.it> 3.10.9-1mamba
- automatic version update by autodist

* Fri Aug 16 2013 Automatic Build System <autodist@mambasoft.it> 3.10.7-1mamba
- automatic version update by autodist

* Thu Aug 08 2013 Automatic Build System <autodist@mambasoft.it> 3.10.5-1mamba
- automatic version update by autodist

* Thu Aug 01 2013 Automatic Build System <autodist@mambasoft.it> 3.10.4-1mamba
- automatic version update by autodist

* Fri Jul 26 2013 Automatic Build System <autodist@mambasoft.it> 3.10.3-1mamba
- automatic version update by autodist

* Mon Jul 22 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.2-1mamba
- update to 3.10.2

* Tue Jul 16 2013 Automatic Build System <autodist@mambasoft.it> 3.10.1-1mamba
- automatic version update by autodist

* Mon Jul 01 2013 Automatic Build System <autodist@mambasoft.it> 3.10-1mamba
- update to 3.10
- source edit: add missing symlink include/uapi/asm required by nvidia

* Wed May 08 2013 Automatic Build System <autodist@mambasoft.it> 3.8.12-1mamba
- update to 3.8.12

* Sun Apr 07 2013 Automatic Build System <autodist@mambasoft.it> 3.8.6-1mamba
- automatic version update by autodist

* Fri Mar 29 2013 Automatic Build System <autodist@mambasoft.it> 3.8.5-1mamba
- automatic version update by autodist

* Thu Mar 21 2013 Automatic Build System <autodist@mambasoft.it> 3.8.4-1mamba
- automatic version update by autodist

* Sun Mar 17 2013 Automatic Build System <autodist@mambasoft.it> 3.8.3-1mamba
- automatic version update by autodist

* Mon Feb 18 2013 Automatic Build System <autodist@mambasoft.it> 3.7.9-1mamba
- automatic version update by autodist

* Sat Feb 16 2013 Automatic Build System <autodist@mambasoft.it> 3.7.8-1mamba
- automatic version update by autodist

* Fri Feb 15 2013 Automatic Build System <autodist@mambasoft.it> 3.7.7-1mamba
- automatic version update by autodist

* Tue Feb 05 2013 Automatic Build System <autodist@mambasoft.it> 3.7.6-1mamba
- automatic version update by autodist

* Wed Jan 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.7.5-2mamba
- fixed wrong requirements for kernelwireless and kernelsound missing -%{kernel_ver} suffix

* Mon Jan 28 2013 Automatic Build System <autodist@mambasoft.it> 3.7.5-1mamba
- automatic version update by autodist

* Thu Jan 24 2013 Automatic Build System <autodist@mambasoft.it> 3.7.4-1mamba
- automatic version update by autodist

* Sat Jan 19 2013 Automatic Build System <autodist@mambasoft.it> 3.7.3-1mamba
- automatic version update by autodist

* Tue Jan 15 2013 Automatic Build System <autodist@mambasoft.it> 3.7.2-1mamba
- automatic version update by autodist

* Sat Dec 22 2012 Automatic Build System <autodist@mambasoft.it> 3.7.1-1mamba
- update to 3.7.1

* Sat Dec 22 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.11-2mamba
- added a patch to libata to restore disable acpi functionality; might fix resume problem seen on Sony Vaio VGN

* Fri Dec 21 2012 Automatic Build System <autodist@mambasoft.it> 3.6.11-1mamba
- update to 3.6.11

* Mon Dec 17 2012 Automatic Build System <autodist@mambasoft.it> 3.6.10-1mamba
- automatic version update by autodist

* Fri Dec 07 2012 Automatic Build System <autodist@mambasoft.it> 3.6.9-1mamba
- automatic version update by autodist

* Sat Dec 01 2012 Automatic Build System <autodist@mambasoft.it> 3.6.8-1mamba
- automatic version update by autodist

* Mon Nov 19 2012 Automatic Build System <autodist@mambasoft.it> 3.6.7-1mamba
- automatic version update by autodist

* Fri Nov 09 2012 Automatic Build System <autodist@mambasoft.it> 3.6.6-1mamba
- automatic version update by autodist

* Fri Nov 02 2012 Automatic Build System <autodist@mambasoft.it> 3.6.5-1mamba
- automatic version update by autodist

* Sun Oct 28 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.4-1mamba
- update to 3.6.4

* Mon Oct 22 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.3-1mamba
- update to 3.6.3

* Sat Oct 13 2012 Automatic Build System <autodist@mambasoft.it> 3.6.2-1mamba
- automatic version update by autodist
- new target: kernel-64GB-rt with RT patch by Ingo Molnar

* Sat Oct 13 2012 Automatic Build System <autodist@mambasoft.it> 3.6.1-1mamba
- update to 3.6.1

* Wed Oct 10 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.13-1mamba
- update to 3.4.13

* Sat Oct 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.12-1mamba
- update to 3.4.12

* Tue Sep 18 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.11-1mamba
- update to 3.4.11
- source edit (next release): set CONFIG_TMPFS_POSIX_ACL=y as required by udisks2

* Wed Sep 05 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.10-1mamba
- update to 3.4.10

* Sat Aug 18 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.9-1mamba
- update to 3.4.9
- apply overlayfs patches (v13) from http://git.kernel.org/?p=linux/kernel/git/mszeredi/vfs.git
- (source edit next-release) added patch to option module to support Huawey E352 on boot

* Tue Aug 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.8-1mamba
- update to 3.4.8

* Wed Aug 01 2012 Automatic Build System <autodist@mambasoft.it> 3.4.7-1mamba
- automatic version update by autodist
- (source edit) prepare setting CONFIG_RTC_DRV_CMOS=y in all configs for next build

* Fri Jul 20 2012 Automatic Build System <autodist@mambasoft.it> 3.4.6-1mamba
- automatic version update by autodist

* Tue Jul 17 2012 Automatic Build System <autodist@mambasoft.it> 3.4.5-1mamba
- automatic version update by autodist

* Thu Jun 28 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.4-1mamba
- update to 3.4.4

* Wed Jun 20 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.21-1mamba
- update to 3.2.21

* Wed Jun 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.19-1mamba
- update to 3.2.19

* Sat Jun 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.18-1mamba
- update to 3.2.18

* Thu May 17 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.17-1mamba
- update to 3.2.17

* Thu May 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.16-1mamba
- update to 3.2.16
- ipw2200 patch from http://marc.info/?l=linux-wireless&m=133486517923084&w=2

* Sat Apr 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.15-1mamba
- update to 3.2.15

* Fri Apr 06 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.14-2mamba
- fix minor release patch application: it was not applied any longer since format is .xz

* Wed Apr 04 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.14-1mamba
- update to 3.2.14

* Mon Mar 26 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.13-1mamba
- update to 3.2.13

* Wed Mar 14 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.11-1mamba
- update to 3.2.11

* Fri Mar 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.9-1mamba
- update to 3.2.9

* Fri Mar 02 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.8-1mamba
- update to 3.2.8

* Tue Feb 21 2012 Automatic Build System <autodist@mambasoft.it> 3.2.7-1mamba
- automatic version update by autodist

* Wed Feb 15 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.6-1mamba
- update to 3.2.6
- configs: disabled deprecated CONFIG_ACPI_PROCFS_POWER
- run grub-set-default 0 to enable reboot from latest release

* Sat Feb 11 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.2.5-1mamba
- update to 3.2.5

* Mon Jan 30 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.10-2mamba
- added patches to fix unresponsiveness and crash due to mm hugepage defrag (https://bugzilla.redhat.com/show_bug.cgi?id=735946)

* Wed Jan 25 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.10-1mamba
- update to 3.1.10

* Mon Nov 14 2011 Automatic Build System <autodist@mambasoft.it> 3.1.1-1mamba
- update to 3.1.1

* Thu Nov 03 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.8-2mamba
- added a patch which fixes firmware task freezing during suspend (seen with mtp-probe and ift-load on macbook pro)

* Mon Oct 31 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.8-1mamba
- update to 3.0.8
- config: enabled CONFIG_PM_TRACE_RTC for resume after suspend debugging (i586 and i586-64GB)

* Sun Oct 23 2011 Automatic Build System <autodist@mambasoft.it> 3.0.7-1mamba
- automatic version update by autodist

* Fri Oct 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-4mamba
- added patches for new ALPS touchpad protocols and ids support (https://bugs.gentoo.org/show_bug.cgi?id=318567)
- config: set psmouse as a module

* Wed Sep 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-3mamba
- config: enabled CONFIG_TIMER_STATS as required by gnome-power-manager
- kernel-wireless: require crda

* Fri Sep 16 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-2mamba
- fix install of modules.builtin, modules.builtin.bin and modules.order in /lib/modules kernel folder

* Sat Sep 03 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.4-1mamba
- update to 3.0.4

* Tue Aug 23 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.4-3mamba
- enable CONFIG_EXT4_FS_SECURITY and CONFIG_SQUASHFS_XATTR

* Sun Aug 21 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.4-2mamba
- require linux-firmware; moved insternally provided firmware files to subpackage -firmware

* Fri Aug 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.4-1mamba
- update to 2.6.39.4

* Sat Jul 09 2011 Automatic Build System <autodist@mambasoft.it> 2.6.39.3-1mamba
- automatic update by autodist

* Thu Jul 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.39.2-1mamba
- update to 2.6.39.2
- reiser4 patch temporary disabled because it is unavailable upstream

* Wed Jul 06 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.38.8-1mamba
- update to 2.6.38.8

* Tue May 10 2011 Automatic Build System <autodist@mambasoft.it> 2.6.38.6-1mamba
- automatic update by autodist

* Mon May 09 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.38.5-2mamba
- unionfs: patch updated to 2.5.9.1_for_2.6.38.4
- fix old provide and obsolete to prevent kernel-mamba-64GB to remove kernel-mamba

* Tue May 03 2011 Automatic Build System <autodist@mambasoft.it> 2.6.38.5-1mamba
- automatic update by autodist

* Wed Apr 27 2011 Automatic Build System <autodist@mambasoft.it> 2.6.38.4-1mamba
- automatic update by autodist

* Tue Apr 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.38.3-1mamba
- update to 2.6.38.3

* Mon Mar 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37.6-1mamba
- update to 2.6.37.6

* Sat Mar 26 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37.5-1mamba
- update to 2.6.37.5

* Tue Mar 15 2011 Automatic Build System <autodist@mambasoft.it> 2.6.37.4-1mamba
- automatic update by autodist

* Tue Mar 08 2011 Automatic Build System <autodist@mambasoft.it> 2.6.37.3-1mamba
- automatic update by autodist

* Mon Feb 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37.2-1mamba
- update to 2.6.37.2
- addded pacthes: vga_dont_ask, unionfs-2.5.7-evict_inode_end_writeback
- restore delay_use patch to fix usb live boot

* Sat Feb 19 2011 Automatic Build System <autodist@mambasoft.it> 2.6.37.1-1mamba
- automatic update by autodist
- added patch to fix flickering problems seen with radeon kms driver

* Sun Feb 06 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.37-1mamba
- update to 2.6.37

* Thu Jan 20 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.35.10-2mamba
- add patch:drm-radeon-r600-cs-checker-fixes to fix 'r600_cs_track_validate_cb:203 cb pitch (64) invalid'

* Thu Dec 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.35.10-1mamba
- update to 2.6.35.10

* Thu Dec 16 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.35.9-1mamba
- update to 2.6.35.9

* Tue Nov 09 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-6mamba
- replace depmod -A with depmod -a to ensure module deps are updated

* Wed Sep 29 2010 Davide Madrisan <davide.madrisan@gmail.com> 2.6.33.7-5mamba
- added patch to prevent tpm driver to hang for a couple of minutes on some hardware

* Sat Sep 18 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-4mamba
- fixed support for VESA framebuffer support by reenabling CONFIG_FB_VESA=y CONFIG_FB_EFI=y
- added patch to support CTI USB-485-Mini and USB-Nano-485 devices
- create failsafe initramfs using dracut in main package (removed -failsafe package)

* Sun Sep 12 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-3mamba
- remove deprecated ATA/ATAPI support in favour of PATA/SATA subsystem
- ppc: some config sync with i586

* Sun Sep 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-2mamba
- removed fbsplash patch; switch to use mkinitrd from dracut with plymouth

* Thu Aug 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.7-1mamba
- update to 2.6.33.7
- added failsafe package with universal initramfs
- fixed mkinitramfs version prerequirement
- moved initramfs creation to posttrans script

* Sun Jul 25 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.6-2mamba
- enabled build of staging drivers (builds nouveau and vmwgfx drm drivers)

* Fri Jul 23 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.6-1mamba
- update to 2.6.33.6
- backport from 2.6.31.13-1mamba:
  exclude scsi/scsi.h from sanitized headers with __u8 type problem, glibc will more properly install its own

* Fri Jun 18 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.33.5-1mamba
- update to 2.6.33.5

* Thu May 13 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.4-1mamba
- automatic update to 2.6.33.4 by autodist

* Mon Apr 26 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.3-1mamba
- automatic update to 2.6.33.3 by autodist

* Wed Apr 07 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.2-1mamba
- automatic update to 2.6.33.2 by autodist

* Mon Mar 15 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33.1-1mamba
- update to 2.6.33.1

* Sun Mar 14 2010 Automatic Build System <autodist@mambasoft.it> 2.6.33-1mamba
- automatic update to 2.6.33 by autodist

* Thu Mar 11 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.31.12-2mamba
- resync patches with kernel 2.6.30.10:
  * added patches for SquashFS with LZMA support
  * 8139too: added patch to keep supporting previous supported chip instead of forcing use of 8139cp

* Fri Mar 05 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.31.12-1mamba
- update to 2.6.31.12

* Sat Jan 16 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.31.11-1mamba
- update to 2.6.31.11

* Tue Nov 10 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.6-1mamba
- automatic update to 2.6.31.6 by autodist

* Fri Oct 23 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.5-1mamba
- automatic update to 2.6.31.5 by autodist

* Tue Oct 13 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.4-1mamba
- automatic update to 2.6.31.4 by autodist

* Sun Sep 27 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31.1-1mamba
- automatic update to 2.6.31.1 by autodist

* Fri Sep 11 2009 Automatic Build System <autodist@mambasoft.it> 2.6.31-1mamba
- update to 2.6.31

* Tue Sep 08 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.5-2mamba
- disabled CONFIG_USB_OHCI_HCD_SSB to prevent ssb.ko crash on some machines with b43 chipset

* Mon Aug 17 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.5-1mamba
- automatic update to 2.6.30.5 by autodist

* Sun Aug 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.4-2mamba
- added wmi patch: Fix kernel panic when stack protection enabled (http://patchwork.kernel.org/patch/32222/)

* Fri Jul 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.4-1mamba
- update to 2.6.30.4

* Wed Jul 29 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.30.3-2mamba
- added patch that exports symbol flush_tlb_page required by fglrx

* Sat Jul 25 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.3-1mamba
- automatic update to 2.6.30.3 by autodist

* Mon Jul 20 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.2-1mamba
- automatic update to 2.6.30.2 by autodist

* Mon Jul 06 2009 Automatic Build System <autodist@mambasoft.it> 2.6.30.1-1mamba
- automatic update to 2.6.30.1 by autodist

* Sat Jun 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.29.5-1mamba
- update to 2.6.29.5

* Tue Jun 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.10-3mamba
- added unionfs patch

* Wed May 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.10-2mamba
- added reiser4 support with external patch

* Tue May 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.10-1mamba
- update to 2.6.28.10
- added MSG_PEEK_race_msg patch to remove an incorrect debug message with fetchmail
  (see www.spinics.net/lists/ntdev/msg96700.html)

* Mon Apr 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.9-2mamba
- fixed application of patchlevel release patch

* Sat Apr 18 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.9-1mamba
- update to 2.6.28.9

* Thu Apr 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.8-3mamba
- added kernel-headers-sanitised package for glibc

* Tue Mar 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.8-2mamba
- IDE support configuration changed to fix boot issues

* Tue Mar 17 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.8-1mamba
- automatic update to 2.6.28.8 by autodist

* Fri Mar 06 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-4mamba
- disable CONFIG_SYSFS_DEPRECATED* for current udev/HAL to work correctly

* Mon Mar 02 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-3mamba
- move new wireless drivers provides by backports to the wireless subpackage

* Mon Feb 23 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-2mamba
- disabled CONFIG_SECURITY_ROOTPLUG to fix boot

* Sat Feb 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.7-1mamba
- update to 2.6.28.7

* Fri Feb 20 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.28.6-1mamba
- update to 2.6.28.6

* Thu Feb 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-6mamba
- enable CONFIG_SYSFS_DEPRECATED_V2 to fix pmount behaviour

* Thu Feb 19 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-5mamba
- added ACPI GPE storm patch (ReHat bug 11089 http://bugzilla.kernel.org/show_bug.cgi?id=11089)

* Sat Jan 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-4mamba
- added requirement for kernelwireless
- run depmod upon kernel-wireless and kernel-sound packages installation

* Mon Jan 12 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-3mamba
- kernel-sound: added virtual provide kernelsound
- kernel-wireless: added virtual provide kernelwireless

* Thu Dec 18 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-2mamba
- rebuilt with snd as a module
- added sound subpackage

* Tue Dec 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.8-1mamba
- update to 2.6.26.8
- unset CONFIG_X86_PAT to prevent video card problems on some systems
- move new wireless drivers to dedicated subpackage
- move MARKER touch from source to headers subpackage

* Mon Sep 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.5-2mamba
- atl1: add patch that disables TSO by default to avoid sendfile() data curruption
- config: enabled time information on printk's

* Sun Sep 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.26.5-1mamba
- update to 2.6.26.5

* Wed Jul 30 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.4mamba
- repackage to fix wrong kernel with old wireless drivers in main package

* Fri Jul 18 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.3mamba
- enabled in it CONFIG_NETDEVICES_MULTIQUEUE for wireless drivers compatibility
- wireless modules provided by wireless-compat (kernel-extramodules) excluded 

* Fri Jun 27 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.2mamba
- remove usbstorage disable delay patch
- mactel patches updated

* Wed May 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-7.1mamba
- update to 2.6.24.7
- excluded drivers usbnet, cdc_ether, rndis_host in favour of usb-rndis-lite 
  drivers in kernel-extramodules

* Mon Mar 24 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-5.1mamba
- update to 2.6.24.5
- added (experimental) kernel-headers subpackage

* Mon Mar 24 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-4.1mamba
- update to 2.6.24.4

* Thu Mar 20 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.4mamba
- removed files in /etc/grub2
- snd_hda_intel: added PCI_QUIRK patch for Acer Aspire 7720G

* Sat Mar 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.3mamba
- build cpu frequency governors as modules; leave userspace as the default

* Fri Mar 07 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.2mamba
- disabled XEN support because it is not supported by NVIDIA drivers

* Fri Mar 07 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-3.1mamba
- update to 2.6.24.3
- realtime_lsm: dropped support (use /etc/security/limits.conf)

* Mon Feb 11 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-2.1mamba
- update to 2.6.24.2

* Sun Feb 10 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-1.1mamba
- update to 2.6.24.1

* Fri Feb 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-0.2mamba
- fixed configuration of fbcondecorpatch (disable FB_TILEBLITTING)
- remove code for suspend2 (resume=)

* Tue Jan 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.24-0.1mamba
- update to 2.6.24
- removed uvesafb patch (included upstream)
- fbsplash patch upgraded (now it is called fbcondecor)

* Tue Jan 15 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-14.1mamba
- update to 2.6.23.14
- squashfs patch: update to 3.3

* Sat Jan 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-13.1mamba
- update to 2.6.23.13
- grub2: launch update-grub
- remove no longer (and never since) used /etc/grub2 contents

* Tue Jan 08 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.4mamba
- set USERSPACE cpu frequency governor as the default (replacing PERFORMANCE)

* Tue Dec 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.3mamba
- added patch to support Zepto notebooks PCIid's

* Mon Dec 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.2mamba
- pass uvesafb instead of vesafb as kernel parameter
- config: removed FB_VESA 
- added requirement for v86d

* Fri Dec 21 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-12.1mamba
- update to 2.6.23.12
- backport of snd_hda_intel from alsa 1.0.15 for Zepto notebooks

* Fri Oct 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.23-1.1mamba
- update to 2.6.23.1
- vesafb_tng patch replaced by uvesafb

* Fri Oct 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-10.1mamba
- update to 2.6.22.10

* Tue Sep 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-8.1mamba
- update to 2.6.22.8

* Sat Sep 22 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-7.1mamba
- update to 2.6.22.7
- CONFIG_HZ set back to 1000 (or audio applications like Rosegarden complain)

* Wed Sep 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-6.2mamba
- disable deprecated option X86_SPEEDSTEP_CENTRINO_ACPI
- ppc: new target build; updated configuration

* Wed Sep 05 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-6.1mamba
- update to 2.6.22.6

* Sun Aug 26 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-5.1mamba
- update to 2.6.22.5

* Thu Aug 16 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-3.1mamba
- update to 2.6.22.3
- kernel-source: declare config/MARKER as ghost file to allow better cleanup on upgrade

* Fri Aug 10 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-2.1mamba
- update to 2.6.22.2

* Wed Jul 18 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-1.2mamba
- mactel patch updated
- CONFIG_HZ set to 300 (was 1000)

* Wed Jul 11 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.22-1.1mamba
- update to 2.6.22.1
- dropped support code for std,old smp,smppreempt and preempt kernels

* Wed Jun 13 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-5.1mamba
- update to 2.6.21.5
- dropped VT3351-disable_msi patch merged upstream

* Mon Jun 11 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-4.3mamba
- fix posttrans script for grub-update execution

* Fri Jun 08 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-4.1mamba
- update to 2.6.21.4
- added support for grub2

* Mon Jun 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-3.2mamba
- add patch that disables NMI on Asus M2V boards (chipset vt3351)
- port of snd_hda_intel driver from alsa 1.0.14
- added patch for kvm (fixes exception #13 qemu error)

* Fri May 25 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-3.1mamba
- update to 2.6.21.3

* Thu May 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-2.1mamba
- update to 2.6.21.2

* Sat Apr 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-1.1mamba
- update to 2.6.21.1

* Thu Apr 26 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.21-0.1mamba
- update to 2.6.21

* Tue Apr 17 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-7.1mamba
- update to 2.6.20.7

* Sat Apr 07 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-6.1mamba
- update to 2.6.20.6

* Fri Apr 06 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-5.1mamba
- update to 2.6.20.5

* Sat Mar 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-4.1qilnx
- update to 2.6.20.4

* Wed Mar 14 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-3.1qilnx
- update to 2.6.20.3

* Mon Mar 12 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-2.1qilnx
- update to 2.6.20.2
- readded suspend2 patch and updated to 2.2.9.9
- fbsplash: update to 0.9.2-r5-2.6.20-rc6

* Sun Mar 04 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-1.2qilnx
- fix wrong symlink from /lib/modules to sources

* Wed Feb 21 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-1.1qilnx
- update to 2.6.20.1

* Fri Feb 16 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-0.3qilnx
- remove suspend2 patch

* Thu Feb 15 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-0.2qilnx
- remove need for theme mamba, will use default instead

* Mon Feb 05 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.20-0.1qilnx
- update to 2.6.20

* Tue Jan 02 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.19-1.1qilnx
- update to 2.6.19.1
- snd_hda_intel: fix a NULL pointer bug
- post script: fix resume2 configuration bug with two or more swap partitions

* Thu Nov 30 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.19-0.1qilnx
- update to 2.6.19

* Mon Nov 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-3.1qilnx
- update to 2.6.18.3

* Wed Nov 15 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-2.3qilnx
- fix and really apply new imac patch

* Tue Nov 14 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-2.2qilnx
- remove realtime preempt patch for mamba target

* Mon Nov 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-2.1qilnx
- update to 2.6.18.2
- set CONSOLE=tty1 for bootsplash
- rt patch: update to rt7
- imac patches updates to current mactel-linux svn + sigmatel patch for microphone

* Fri Oct 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-1.2qilnx
- rt patch: update to rt6
- rename packages from kernel26 to kernel

* Sat Oct 14 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-1.1qilnx
- new build for 2.6.18.1 patch release

* Sun Oct 08 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.5qilnx
- add suspend2 patch
- add realtime lsm patch (updated to 0.8.7 and moved from kernel26-extramodules)
- enable EEPRO100 ethernet driver module
- enable as built-in the LZF compression algohorithm needed by suspend2

* Wed Oct 04 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.4qilnx
- disable bootsplash fadein
- set PERFORMANCE CPUFREQ governor (for test pourposes against USERSPACE)

* Sun Sep 30 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.3qilnx
- rt5 patch applied
- build usbhid as a module because appletouch module has to be loaded before

* Thu Sep 28 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.2qilnx
- dropped ck preemptible kernel patch in favour of Ingo Molnar's realtime patch

* Thu Sep 21 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.18-0.1qilnx
- new kernel release build
- squashfs update to 3.1-r2

* Sun Jul 16 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-6.1qilnx
- new kernel subrelease build

* Tue Jul 11 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-4.2qilnx
- added applesmc patch for MacBook motion/light sensors and keyboard backlight

* Fri Jul 07 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-4.1qilnx
- kernel update to 2.6.17.4
- added sigmatel patch to make audio work on 15" MacBook Pro's
- removed imacfb
- added radeonfb and matroxfb builtin

* Wed Jul 05 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-3.1qilnx
- kernel update to 2.6.17.3
- add support for initramfs

* Wed Jun 30 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-2.1qilnx
- kernel update to 2.6.17.2
- mamba: loop device modules built-in
- mamba: console framebuffer device build as module
- removed bootsplash patch
- added fbsplash patch
- added vesafb-tng patch

* Tue Jun 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-1.1qilnx
- kernel update to 2.6.17.1
- new kernel target "mamba"

* Tue Jun 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.17-0.1qilnx
- kernel update to 2.6.17
- added cleane headers patch from -mm

* Wed Jun 07 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.16-20.1qilnx
- kernel update to 2.6.16.20

* Sat May 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-16.1qilnx
- kernel update to 2.6.16.16
- ck patch update to 2.6.16-ck10
- set CONFIG_VMSPLIT_3G again because of problems with wine and valgrind
- kernel smppreempt: set PENTIUMIII as target processor

* Mon May 08 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-14.1qilnx
- kernel patch release update to 2.6.16.14
- ck patches update to 2.6.16-ck9 

* Sun Apr 23 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-9.2qilnx
- removed %posttrans script, moved to %post ($1 variable is not handled)

* Fri Apr 21 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-9.1qilnx
- add rtc in kernel monolith
- set CONFIG_VMSPLIT_2G for iMacs
- added imacfb
- set PCI_MSI=y on all i586 configs
- set CONFIG_BLK_DEV_SD=y, CONFIG_SCSI_SATA_AHCI=y on all i586 configs

* Mon Apr 17 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-5.2qilnx
- add support for EFI boot and partitions

* Thu Apr 13 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-5.1qilnx
- new subrelease build
- Intel Mac patch from Mac-Tel added for Intel Macs
- add support for new smppreempt target

* Mon Mar 20 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.16-0.1qilnx
- new version build
- create symlinks /dev/loop[0-2] if missing (for update from QiLinux 1.2)
- execute lilo-config --killdevfs (for update from QiLinux 1.2)

* Wed Feb 22 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-4.2qilnx
- ck preempt-realtime patch update to ck4
- ACPI sleep states support enabled

* Fri Feb 10 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-4.1qilnx
- new subrelease build
- remove lilo prereq

* Wed Feb 08 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-3.1qilnx
- new subrelease build
- added initial grub support

* Wed Jan 11 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.15-0.1qilnx
- new kernel version build

* Mon Dec 19 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-4.1qilnx
- new subrelease build
- added distcc build support

* Mon Dec 12 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-3.2qilnx
- preempt: remove ck's prefetch of swap pages
- preempt: disable AS and deadline I/O scheduling

* Wed Dec 02 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-3.1qilnx
- new rt patch rt21
- new subrelease build
- add Con Kolivas patch to preempt and rt targets

* Fri Nov 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-2.2qilnx
- new single target specfile
- rename kernel26 to kernel
- change subpkgs names from kernel-<extra>-<target> to kernel-<target>-<extra>

* Wed Nov 16 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.14-2.1qilnx
- new kernel version build

* Sat Nov 12 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-4.3qilnx
- rt_preempt: fix missing export for tsc_c3_compensate symbol

* Fri Nov 11 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-4.2qilnx
- preempt: disabled realtime preemption
- preempt: disabled CONFIG_SPINLOCK_BKL

* Sat Nov 05 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-4.1qilnx
- new subrelease build
- add realtime-preempt patch to preempt target

* Thu Oct 06 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-3.1qilnx
- new version build

* Tue Sep 20 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-2.1qilnx
- new version build
- ppc target fixes in scripts

* Sat Sep 10 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.13-1.1qilnx
- new version build

* Wed Aug 10 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-4.1qilnx
- new subrelease build

* Mon Jul 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-3.1qilnx
- new subrelease build

* Thu Jun 30 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-2.1qilnx
- new subrelease build
- disabled devfs mount on boot (requires new mkinitrd)

* Mon Jun 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.12-1.1qilnx
- new version build

* Wed Jun 22 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.12-1qilnx
- supermount patch disabled (see http://bhhdoa.org.au/pipermail/ck/2005-May/003462.html)

* Sun May 29 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.11-1qilnx
- new version build
- built kernels processor type changed to Pentium-Pro (686)
- added patchlevel support for modules (installed to 2.6.11 modules dir)

* Sun May 15 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.9-1qilnx
- new version build
- fixed lilo updates problem (added release to files)
- also fixes CAN-2005-1263 security vulnerability

* Sun Apr 30 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.8-1qilnx
- new versiion build
- lilo-config: add --keep-default option to %pre scripts

* Wed Apr 27 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.6-4qilnx
- add patch to remove 8139cp hotplugging for Realtek 8139 cards and use 8139too instead

* Thu Mar 31 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.11.6-3qilnx
- changes in %%pre and %%postun scriptlets required by the new lilo-config tool

* Wed Mar 30 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.6-2qilnx
- changed lilo-config and mkinitrd execution order for bootsplash configuration

* Tue Mar 29 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.6-1qilnx
- new version build (also fix security issues: CAN-2005-[0400,0794,0794,0815])
- added specfile support for pl releases patches
- removed rpm release from lilo.d configuration file names

* Mon Mar 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.11.5-1qilnx
- new version build
- scriptlets modified (kernel26 requires the new lilo-config script)
- set vga=0x314 in the lilo kernel blocks

* Thu Mar 17 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.11.4-1qilnx
- new version build

* Tue Mar 08 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.11.1-1qilnx
- new version build
- preempt kernel: added supermount-ng patch 2.08

* Mon Feb 28 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-6qilnx
- rebuilt with 4GB high memory support

* Sun Feb 20 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-5qilnx
- rebuilt with security capabilities as a module and with linux SE enabled

* Tue Jan 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-4qilnx
- rebuild with SCSI sg (generic) support as a module and not built-in

* Tue Jan 11 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-3qilnx
- rebuild with ide_scsi as a module and not built-in

* Thu Dec 30 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-2qilnx
- rebuilt with gcc 3.4

* Thu Dec 30 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.10-1qilnx
- new version build

* Wed Dec 01 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.9-2qilnx
- rebuilt with security capabilities build-in and not as a module

* Mon Nov 08 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.9-1qilnx
- new version build

* Sun Aug 15 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.8.1-2qilnx
- fix build script because Kernel Makefile extraver is .1 and not null 
  (replace it with .1,.1smp and .1preempt)

* Sun Aug 15 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.8.1-1qilnx
- new version build
- added directory /sys (insted of it being created by mountproc initscript)
- lilo label renamed to qilinux-26<extraver>

* Wed Jul 07 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.7-3qilnx
- added "make prepare-all" needed to build the kernel26-extramodules 
  package

* Mon Jun 28 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.7-2qilnx
- rebuild without cloop module (it is now in kernel-extramodules)

* Fri Jun 18 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.7-1qilnx
- new version build
- added cloop module built-in compile

* Thu May 20 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.6-3qilnx
- moved code from %post scriptlets to /sbin/lilo-config (lilo package)

* Tue May 18 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.6-2qilnx
- rebuild for standard, smp and preempt targets

* Mon May 10 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.6-1qilnx
- rebuilt with kernel-2.6.6

* Mon Apr 05 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.5-1qilnx
- rebuilt with kernel-2.6.5

* Thu Mar 25 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.4-2qilnx
- added more kernel modules
- fixed post script

* Fri Mar 12 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.4-1qilnx
- rebuilt with version 2.6.4

* Sat Jan 10 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.1-1qilnx
- rebuilt with version 2.6.1

* Thu Dec 18 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.0-1qilnx
- rebuilt with the new born 2.6.0 version :)

* Sat Nov 22 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.0test9-1qilnx
- fixed some kernel boot problems

* Sat Oct 25 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.6.0test8-1qilnx
- first building of a kernel from branch 2.6.x
